git\_stacktrace package
=======================

Submodules
----------

git\_stacktrace\.api module
---------------------------

.. automodule:: git_stacktrace.api
    :members:
    :undoc-members:
    :show-inheritance:

git\_stacktrace\.cmd module
---------------------------

.. automodule:: git_stacktrace.cmd
    :members:
    :undoc-members:
    :show-inheritance:

git\_stacktrace\.git module
---------------------------

.. automodule:: git_stacktrace.git
    :members:
    :undoc-members:
    :show-inheritance:

git\_stacktrace\.parse\_trace module
------------------------------------

.. automodule:: git_stacktrace.parse_trace
    :members:
    :undoc-members:
    :show-inheritance:

git\_stacktrace\.result module
------------------------------

.. automodule:: git_stacktrace.result
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: git_stacktrace
    :members:
    :undoc-members:
    :show-inheritance:
